@@ -106,6 +106,7 @@ extern int deluser(char *, char *);
 extern int delusermask(char *, char *, char *);
 extern int deltrusted(char *);
 extern int delchannel(char *);
+extern int deladverts(char *, char *);
 extern int getondiskmsgcount(char *, char *);
 extern int getondiskjoincount(char *, char *);
 extern int getrandom(int);
@@ -145,7 +146,6 @@ extern struct chanuser *getrandomuser(char *);
 extern struct ls_wrapstruct *addnew_ls(struct ls_wrapstruct *, time_t, char *, char *, char *);
 extern time_t lastoff(char *, char *, char *);
 extern void sendadverts(char *, char *, char *);
-extern void deladverts(char *, char *);
 extern void resetparts(char *, char *, char *);
 extern void iamop(char *, int);
 extern void initpubmsgs(char *);
