@@ -230,12 +230,15 @@ enum OER_DEBUG_LEVELS {
 	OER_DEBUG_FLOOD = 9
 };
 
-enum OER_ADVERT_TYPES {
-        OER_ADVERT_TYPE_LAMERS,
-        OER_ADVERT_TYPE_BOTUSERS_OPS,
-        OER_ADVERT_TYPE_BOTUSERS_ADMINS,
-        OER_ADVERT_TYPE_BOTUSERS_OTHER,
-        OER_ADVERT_TYPE_INVALID
+enum OER_BAN_TYPES {
+        OER_BAN_TYPE_HOST = 1,
+        OER_BAN_TYPE_USER,
+        OER_BAN_TYPE_USER_HOST,
+        OER_BAN_TYPE_NICK,
+        OER_BAN_TYPE_NICK_HOST,
+        OER_BAN_TYPE_NICK_USER,
+        OER_BAN_TYPE_NICK_USER_HOST,
+        OER_BAN_TYPE_INVALID
 };
 
 #define numofparams(x) (wordcount(x) - 1)
@@ -270,12 +273,15 @@ enum OER_ADVERT_TYPES {
 #define OER_QUOTE_INTERVAL 300
 #define OER_ALLOWED_PARTS OER_PARTS / 5
 #define OER_RECONNECT_DELAY 30
+#define OER_NETJOIN_DELAY 15
 #define OER_PUBMSGS 20
 #define OER_SERVER_IS_STONED_FOR 300
 #define OER_MASSMODE_LIMIT 3
-#define OER_LASTS 3
+#define OER_LAST 3
+#define OER_LAST_MAX 10
 #define OER_LAST_MAX_LENGTH 120
 #define OER_SEEN 3
+#define OER_SEEN_MAX 10
 #define OER_TOPICS 20
 #define OER_TOPICLEN 160
 #define OER_PERMBANS 25
@@ -319,7 +325,7 @@ enum OER_ADVERT_TYPES {
 #define OER_HELP "For a complete command reference go to http://oer.equnet.org/help.html"
 #define DEFAULT_NICKBK_MESSAGE "prohibited nick"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
-#define OER_COPYRIGHT1 "oer+MySQL version 1.0-16, Copyright (C) 2000-2001 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer+MySQL version 1.0-17, Copyright (C) 2000-2001 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer+MySQL comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
@@ -362,7 +368,7 @@ struct locked {
 
 struct chanuser {
 	char *nick;
-	char *host;
+	char *userhost;
 	int hostquery;
 	int ircop;
 	int chanop;
@@ -384,7 +390,7 @@ struct botuser {
 struct authed {
 	time_t at;
 	struct botuser *user;
-	char *host;
+	char *userhost;
 	struct authed *prev;
 	struct authed *next;
 };
@@ -413,7 +419,7 @@ struct timed {
 struct pubmsg {
 	time_t at;
 	char *nick;
-	char *host;
+	char *userhost;
 	char *message;
 	struct pubmsg *prev;
 	struct pubmsg *next;
@@ -422,7 +428,7 @@ struct pubmsg {
 struct join {
 	time_t at;
 	char *nick;
-	char *host;
+	char *userhost;
 	struct join *prev;
 	struct join *next;
 };
@@ -431,7 +437,7 @@ struct part {
 	time_t at;
 	int valid;
 	char *nick;
-	char *host;
+	char *userhost;
 	struct part *prev;
 	struct part *next;
 };
@@ -444,7 +450,7 @@ struct maskstruct {
 };
 
 struct advert {
-        char *type;
+        char *to;
         char *message;
         struct advert *prev;
         struct advert *next;
@@ -481,6 +487,7 @@ struct channel {
 	int topic_change;
 	int topic_reset;
 	int synced;
+        int bantype;
 	time_t rejoin_at;
 	time_t last_quote;
 	time_t userts;
